"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../../base");
const fetcher_1 = require("../../../../lib/fetcher");
class Add extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Add);
        const database = await (0, fetcher_1.default)(this.heroku, args.database, flags.app);
        const { 'aws-account-id': account_ids } = flags;
        const accountFormatted = account_ids.length > 1 ? 'accounts' : 'account';
        core_1.ux.action.start(`Adding ${accountFormatted}`);
        await this.shogun.put(`/private-link/v0/databases/${database}/allowed_accounts`, Object.assign(Object.assign({}, this.shogun.defaults), { body: {
                allowed_accounts: account_ids,
            } }));
        core_1.ux.action.stop();
    }
}
exports.default = Add;
Add.description = 'add one or more allowed AWS accounts to your privatelink endpoint';
Add.hiddenAliases = ['pg:privatelink:access:add', 'kafka:privatelink:access:add', 'redis:privatelink:access:add'];
Add.args = {
    database: core_1.Args.string({ required: true }),
};
Add.flags = {
    'aws-account-id': command_1.flags.string({
        char: 'i',
        description: 'AWS account id to use',
        required: true,
        multiple: true,
    }),
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Add.examples = [
    '$ heroku data:privatelink:access:add postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --app my-app',
    '$ heroku data:privatelink:access:add postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --aws-account-id 123456789012:user/xyz --app my-app',
];
