"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../../base");
const fetcher_1 = require("../../../../lib/fetcher");
class Index extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Index);
        const database = await (0, fetcher_1.default)(this.heroku, args.database, flags.app);
        const { body: { allowed_accounts } } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
        if (allowed_accounts.length > 0) {
            core_1.ux.table(allowed_accounts, {
                arn: {
                    header: 'ARN',
                },
                status: {
                    header: 'Status',
                },
            });
        }
        else {
            core_1.ux.log('There are no allowed accounts');
        }
    }
}
exports.default = Index;
Index.topic = 'data:privatelink:access';
Index.description = 'list all allowed accounts for your privatelink endpoint';
Index.hiddenAliases = ['pg:privatelink:access', 'kafka:privatelink:access', 'redis:privatelink:access'];
Index.args = {
    database: core_1.Args.string({ required: true }),
};
Index.flags = {
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Index.examples = [
    '$ heroku data:privatelink:access postgresql-sushi-12345 --app my-app',
];
