"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../../base");
const fetcher_1 = require("../../../../lib/fetcher");
class Remove extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Remove);
        const database = await (0, fetcher_1.default)(this.heroku, args.database, flags.app);
        const { 'aws-account-id': account_ids } = flags;
        const accountFormatted = account_ids.length > 1 ? 'accounts' : 'account';
        core_1.ux.action.start(`Removing ${accountFormatted}`);
        await this.shogun.patch(`/private-link/v0/databases/${database}/allowed_accounts`, Object.assign(Object.assign({}, this.shogun.defaults), { body: {
                allowed_accounts: account_ids,
            } }));
        core_1.ux.action.stop();
    }
}
exports.default = Remove;
Remove.description = 'remove an allowed account from your privatelink endpoint';
Remove.hiddenAliases = ['pg:privatelink:access:remove', 'kafka:privatelink:access:remove', 'redis:privatelink:access:remove'];
Remove.args = {
    database: core_1.Args.string({ required: true }),
};
Remove.flags = {
    'aws-account-id': command_1.flags.string({
        char: 'i',
        description: 'AWS account id to use',
        required: true,
        multiple: true,
    }),
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Remove.examples = [
    '$ heroku data:privatelink:access:remove postgresql-sushi-12345 --aws-account-id 123456789012:user/xyz --app my-app',
    '$ heroku data:privatelink:access:remove postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --aws-account-id 123456789012:user/xyz --app my-app',
];
