"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../base");
const fetcher_1 = require("../../../lib/fetcher");
class Create extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Create);
        const database = await (0, fetcher_1.default)(this.heroku, args.database, flags.app);
        const { 'aws-account-id': account_ids, app } = flags;
        core_1.ux.action.start('Creating privatelink endpoint');
        const { body: res } = await this.shogun.post(`/private-link/v0/databases/${database}`, Object.assign(Object.assign({}, this.shogun.defaults), { body: {
                allowed_accounts: account_ids,
            } }));
        core_1.ux.action.stop();
        core_1.ux.log();
        core_1.ux.styledObject({
            Status: res.status,
            'Service Name': res.service_name || 'Provisioning',
        });
        core_1.ux.log();
        core_1.ux.log(`The privatelink endpoint is now being provisioned for ${color_1.default.green(database)}.`);
        core_1.ux.log('Run ' + color_1.default.cmd('heroku data:privatelink:wait ' + database + ' --app ' + app) +
            ' to check the creation process.');
    }
}
exports.default = Create;
Create.description = 'create a new privatelink endpoint for your database';
Create.hiddenAliases = ['pg:privatelink:create', 'kafka:privatelink:create', 'redis:privatelink:create'];
Create.args = {
    database: core_1.Args.string({ required: true }),
};
Create.flags = {
    'aws-account-id': command_1.flags.string({
        char: 'i',
        description: 'AWS account id to use',
        required: true,
        multiple: true,
    }),
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Create.examples = [
    '$ heroku data:privatelink:create postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --app my-app',
    '$ heroku data:privatelink:create postgresql-sushi-12345 --aws-account-id 123456789012:user/abc --account-id 123456789012:user/xyz --app my-app',
];
