"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const color_1 = require("@heroku-cli/color");
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../base");
const fetcher_1 = require("../../../lib/fetcher");
class Index extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Index);
        const { app } = flags;
        const database = await (0, fetcher_1.default)(this.heroku, args.database, app);
        const { body: res } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
        const addonType = this.addonType(res.addon.name);
        if (res.status === 'Provisioning') {
            core_1.ux.log();
            core_1.ux.log(`The privatelink endpoint is now being provisioned for ${color_1.default.green(database)}.`);
            core_1.ux.log(`Run ${color_1.default.cmd(`heroku data:privatelink:wait -a ${app}`)} to check the creation process.`);
        }
        else {
            core_1.ux.styledHeader(`privatelink endpoint status for ${color_1.default.green(database)}`);
            core_1.ux.styledObject({
                Status: res.status,
                'Service Name': res.service_name || 'Provisioning',
            });
            if (res && res.allowed_accounts.length > 0) {
                core_1.ux.log();
                core_1.ux.styledHeader('Allowed Accounts');
                core_1.ux.table(res.allowed_accounts, {
                    arn: { header: 'ARN' },
                    status: {},
                });
            }
            core_1.ux.log();
            if (res && res.connections.length > 0) {
                core_1.ux.styledHeader('Connections');
                core_1.ux.table(res.connections, {
                    endpoint_id: { header: 'Endpoint ID' },
                    owner_arn: { header: 'Owner ARN' },
                    status: {},
                });
            }
            else if (res.status === 'Operational' && res.connections.length === 0) {
                core_1.ux.log('Your privatelink endpoint is now operational.');
                core_1.ux.log(`You must now copy the ${color_1.default.green('Service Name')} and follow the rest of the steps listed in https://devcenter.heroku.com/articles/heroku-${addonType}-via-privatelink`);
            }
        }
    }
    addonType(addon_name) {
        if (addon_name.includes('postgres'))
            return 'postgres';
        if (addon_name.includes('kafka'))
            return 'kafka';
        if (addon_name.includes('redis'))
            return 'redis';
    }
}
exports.default = Index;
Index.topic = 'data:privatelink';
Index.description = 'list all your privatelink endpoints';
Index.hiddenAliases = ['pg:privatelink', 'kafka:privatelink', 'redis:privatelink'];
Index.args = {
    database: core_1.Args.string({ required: true }),
};
Index.flags = {
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Index.examples = [
    '$ heroku data:privatelink postgresql-sushi-12345 --app my-app',
];
