"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@heroku-cli/command");
const core_1 = require("@oclif/core");
const base_1 = require("../../../base");
const fetcher_1 = require("../../../lib/fetcher");
class Wait extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(Wait);
        const database = await (0, fetcher_1.default)(this.heroku, args.database, flags.app);
        let status;
        core_1.ux.action.start('Waiting for the privatelink endpoint to be provisioned');
        while (status !== 'Operational') {
            const { body: res } = await this.shogun.get(`/private-link/v0/databases/${database}`, this.shogun.defaults);
            status = res.status;
            await core_1.ux.wait(3000);
        }
        core_1.ux.action.stop();
    }
}
exports.default = Wait;
Wait.description = 'wait for your privatelink endpoint to be provisioned';
Wait.hiddenAliases = ['pg:privatelink:wait', 'kafka:privatelink:wait', 'redis:privatelink:wait'];
Wait.args = {
    database: core_1.Args.string({ required: true }),
};
Wait.flags = {
    app: command_1.flags.app({ required: true }),
    remote: command_1.flags.remote(),
};
Wait.examples = [
    '$ heroku data:privatelink:wait postgresql-sushi-12345 postgresql-sushi-12345 --app my-app',
];
